@@ -14,7 +14,7 @@ zeta2.coef<-function(mat,H,r,indices,tolval=10*.Machine$double.eps,tolsym=1000*.
 
 
   p <- dim(mat)[2]
-  validmat(mat,p,tolval,tolsym)
+  validmat(mat,p,tolval,tolsym,allowsingular=TRUE,algorithm="none")
 
 
 # checks on r and H
