@@ -17,7 +17,7 @@ int callsscma(double *S,double *S2,double *Si,double *Segval,double *Segvct,
 	double wilksval,double bartpival,double lawhotval,double ccr12val,int r,
 	int kmin,int kmax,int nsol,int *out,int *in,int nout,int nin,
 	const char *cmpcr,int fixed,int *pcind,int nind,int nvar,double timelimit,
-	double ntol,int *found,bool onlyforward,int *subs,double *subsv,double *bestsv,int *bests,
+	double ntol,bool onlyforward,int *subs,double *subsv,double *bestsv,int *bests,
 	bool printmsg);
 }
 
